@@ -94,11 +94,11 @@ demix <- function(x = NULL,
     output <- .C("RPreprocessingH",
       h = as.double(h),
       y0 = as.double(y0),
-      ParFamType = as.character(pdf),
+      Theta.pdf = as.character(pdf),
       k = as.integer(k),
       n = as.integer(n),
       d = as.integer(d),
-      object = as.double(unlist(x)),
+      x = as.double(unlist(x)),
       y = double(n * (d + 1)),
       error = integer(1),
       PACKAGE = "rebmix")
@@ -133,7 +133,7 @@ demix <- function(x = NULL,
       h = as.double(h),
       n = as.integer(n),
       d = as.integer(d),
-      object = as.double(unlist(x)),
+      x = as.double(unlist(x)),
       y = double(n * (d + 2)),
       error = integer(1),
       PACKAGE = "rebmix")
@@ -163,7 +163,7 @@ demix <- function(x = NULL,
       h = as.double(h),
       n = as.integer(n),
       d = as.integer(d),
-      object = as.double(unlist(x)),
+      x = as.double(unlist(x)),
       y = double(n * (d + 3)),
       error = integer(1),
       PACKAGE = "rebmix")
